@@ -3,8 +3,8 @@
 from __future__ import absolute_import, unicode_literals
 
 __author__  = 'Jefurry <jefurry@qq.com>'
-__version__ = '0.2.0'
 
+from pyar.version import __version__
 import traceback
 from sqlbuilder import smartsql as sb
 from pyar import exc, url, util, result
@@ -29,17 +29,6 @@ SMARTSQL_DIALECTS = {
     'oracle': 'oracle',
 }
 
-logger = util.getLogger('pyar')
-def dumpSQL(sql, params, using='default'):
-    tpl = '''
-    --- SQL DUMP ---
-    using: {0}
-    {1} - {2}
-    --- END DUMP ---
-    '''
-    print tpl.format(using, sql, params)
-    #logger.debug(tpl, using, sql, params)
-
 NoneResult    = result.Result(None)
 NoneRowResult = result.RowResult(None)
 
@@ -52,15 +41,11 @@ class ModelBase(object):
     _tb_name_      = None
 
 class Model(ModelBase):
-    db      = None
     qs      = None
+    _db     = None
     _conn   = None
     _db_key = None
     _tb_key = None
-    #T, TA, F, A, E, qs = sb.Table, sb.TableAlias, sb.Field, sb.Alias, sb.Expr, sb.QuerySet
-    #const = sb.ConstantSpace()
-    #func = sb.const
-    #qn = sb.Name()
 
     def __init__(self):
     	_using      = None
@@ -71,7 +56,6 @@ class Model(ModelBase):
     	if _using is None:
     		_using = 'default'
         self._using = _using
-
     	_dns = pyar.settings.DNS.get(_using, None)
         if not _dns:
         	raise exc.DnsStringNotFoundError(
@@ -80,8 +64,8 @@ class Model(ModelBase):
             _dns_url = url.make_url(_dns)
             _dialect = _dns_url.get_dialect()
             if issubclass(_dialect, connection.Database):
-                self.db    = _dialect(_using, _dns_url)
-                self._conn = self.db.getconn()
+                self._db   = _dialect(_using, _dns_url)
+                self._conn = self._db.getconn()
                 _tbname    = None
                 if hasattr(self, '_tb_name_'):
                     if callable(self._tb_name_) and hasattr(self, '_tb_key'):
@@ -121,8 +105,8 @@ class Model(ModelBase):
 
     def _execute(self, sql, params, action=None):
         if self._debug_:
-            dumpSQL(sql, params, self._using)
-        _cur    = self.db.getcur(self._conn)
+            self._db.dumpSQL(sql, params, self._using)
+        _cur    = self._db.getcur(self._conn)
         _dbname = None
         if hasattr(self, '_db_name_'):
             if callable(self._db_name_) and hasattr(self, '_db_key'):
@@ -132,7 +116,7 @@ class Model(ModelBase):
         if _dbname:
             _cur.execute('USE `%s`' % (_dbname,))
 
-        _res    = _cur.execute(self.db.prepare(sql), params)
+        _res    = _cur.execute(self._db.prepare(sql), params)
         _lastid = None
         if action == 'insert':
             _lastid = _cur.lastrowid
@@ -159,7 +143,7 @@ class Model(ModelBase):
             return self._execute(sql[0], sql[1], 'insert')
         except Exception as e:
             if self._debug_:
-                logger.debug(e)
+                util.logger.debug(e)
             raise exc.DBOperationError("Database Operation Error: '%s'." % (e,))
 
     def _select(self, sql, flag='select_all'):
@@ -167,7 +151,7 @@ class Model(ModelBase):
             return self._execute(sql[0], sql[1], flag)
         except Exception as e:
             if self._debug_:
-                logger.debug(e)
+                util.logger.debug(e)
             raise exc.DBOperationError("Database Operation Error: '%s'." % (e,))
 
     def all(self, sql):
@@ -178,7 +162,7 @@ class Model(ModelBase):
             return result.Result.new(_res)
         except Exception as e:
             if self._debug_:
-                logger.debug(e)
+                util.logger.debug(e)
             raise exc.DBOperationError("Database Operation Error: '%s'." % (e,))
 
     def first(self, sql):
@@ -189,9 +173,12 @@ class Model(ModelBase):
             return result.RowResult.new(_res)
         except Exception as e:
             if self._debug_:
-                logger.debug(e)
+                util.logger.debug(e)
             raise exc.DBOperationError("Database Operation Error: '%s'." % (e,))
 
+    def one(self, sql):
+        return self.first(sql)
+
 
     def count(self, sql):
         try:
@@ -203,7 +190,7 @@ class Model(ModelBase):
             return 0
         except Exception as e:
             if self._debug_:
-                logger.debug(e)
+                util.logger.debug(e)
             raise exc.DBOperationError("Database Operation Error: '%s'." % (e,))
 
     def update(self, sql):
@@ -212,7 +199,7 @@ class Model(ModelBase):
             return self._execute(sql[0], sql[1], 'update')
         except Exception as e:
             if self._debug_:
-                logger.debug(e)
+                util.logger.debug(e)
             raise exc.DBOperationError("Database Operation Error: '%s'." % (e,))
 
     def delete(self, sql):
@@ -221,12 +208,12 @@ class Model(ModelBase):
             return self._execute(sql[0], sql[1], 'delete')
         except Exception as e:
             if self._debug_:
-                logger.debug(e)
+                util.logger.debug(e)
             raise exc.DBOperationError("Database Operation Error: '%s'." % (e,))
 
     def end(self):
         try:
-            self.db.putconn(self._conn)
+            self._db.putconn(self._conn)
             self._conn = None
         except:
             pass
@@ -242,74 +229,6 @@ class Model(ModelBase):
         del self
         if _traceback is not None:
             if _debug:
-                print "with exit error: ", traceback.format_exc()
+                util.logger.debug("with exit error: ", traceback.format_exc())
             return False
         return True
-
-
-if __name__ == '__main__':
-    import time, sys
-
-    pyar.settings.DNS = {
-    'default' : 'mysql://root:@localhost:3306/davos?use_unicode=0&charset=utf8&mincached=20&maxcached=100',
-    }
-
-    class DavosDatabase(Model):
-        _debug_ = True
-        _using_ = 'default'
-
-    class AppModel(DavosDatabase):
-        _tb_name_ = 'app'
-        _db_name_ = lambda cls, key: 'davos'
-
-    a = AppModel()
-    _time = int(time.time())
-    s = a.qs.insert({'user_id' : 1, 
-        'title' : 'good,night', 
-        'name' : 'test', 
-        'description' : "'ttt'", 
-        'ctime' : _time, 
-        'mtime' : _time, 
-        'enable' : 1})
-
-    #print s
-    a.insert(s)
-    #print a.qs.where(sb.F.id==2).select('*')
-    print '---------------------------------------'
-    a.count(a.qs.count('*'))
-    print '---------------------------------------'
-    #print a.qs.where(sb.F.id==2).update({'title' : 'goal'})
-    a.update(a.qs.where(sb.F.id>2).update({'title' : 'goal'}))
-    print '---------------------------------------'
-    #print a.qs.where(sb.F.id==2).delete()
-    a.delete(a.qs.where(sb.F.id>260).delete())
-    print '---------------------------------------'
-    res = a.all(a.qs.where(sb.F.id==1).select('*'))
-    print res.id, res.name
-    for row in res:
-        print row.name, row.id, '@===@'
-    print "raw: ", res.raw()
-    res2 = a.all(a.qs.where(sb.F.id==2).select('*'))
-    print "+++++++++++++++++++++++++++++++++++++++++++++++"
-    print ".....", (res + res2).raw(), "...."
-    print "+++++++++++++++++++++++++++++++++++++++++++++++"
-    print '---------------------------------------'
-    res3 = a.first(a.qs.select('*'))
-    print res3.id, res3.name
-    for k, v in res3:
-        print k, v, '*===*'
-    print "raw: ", res3.raw()
-    print "????", (res + res).raw(), "????"
-    print "$$$$", result.Result.fromRowResult(res3).raw(), "$$$$"
-    print '---------------------------------------'
-    print "###", res | None, result.RowResult.new() | res, "###"
-    print '---------------------------------------'
-    print "isinstance: ", isinstance(res, result.ResultProxy), "issubclass: ", issubclass(res.__class__, result.ResultProxy)
-    print "new: ", res3.raw(), '---', res.raw(), '---', (res3 + res).raw(), '---', (res3 + {'a':'b'}).raw()
-    print "+++: ", (res3 + res3).raw()
-    print "************************************************************************"
-    print '--------', (((res + {'gg':'goal'}) + res3) + res).raw(), '---------------'
-    print type((res + {'gg':'goal'}) + res3)
-    del a
-    #print sb.QS(getattr(sb.T, 'user_98')).where((sb.F.status == 1) & (sb.F.a == 'go')).delete()
-    #print u.tables(sb.T.good).select('*')
