@@ -44,3 +44,6 @@ class Database(object):
 
     def prepare(self, sql):
         raise NotImplementedError('This method should return a connection.')
+
+    def dumpSQL(self, sql, params, using):
+        raise NotImplemented('This method should return a connection.')
